@@ -7,7 +7,7 @@
  */
 
 #include "modifyjob.h"
-#include "../debug.h"
+#include "debug.h"
 #include "object.h"
 
 #include <QNetworkAccessManager>
