@@ -6,8 +6,7 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef LIBKGAPI2_REFRESHTOKENSJOB_P_H
-#define LIBKGAPI2_REFRESHTOKENSJOB_P_H
+#pragma once
 
 #include "job.h"
 #include "kgapicore_export.h"
@@ -40,6 +39,5 @@ private:
 
 } // namespace KGAPI2
 
-#endif
 
 
